
.. automodule:: bci_framework.extensions.data_analysis
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   bci_framework.extensions.data_analysis.data_analysis
   bci_framework.extensions.data_analysis.utils
